package com.qs.mp.web.controller.api.admin;

import com.qs.mp.admin.domain.param.MarketingCreateParam;
import com.qs.mp.admin.domain.param.MarketingQueryParam;
import com.qs.mp.admin.domain.param.MarketingUpdateParam;
import com.qs.mp.admin.domain.vo.MarketingListVO;
import com.qs.mp.admin.service.IMarketingService;
import com.qs.mp.common.annotation.Log;
import com.qs.mp.common.core.domain.AjaxResult;
import com.qs.mp.common.core.page.TableDataInfo;
import com.qs.mp.common.enums.BusinessType;
import com.qs.mp.web.controller.common.BaseApiController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 营销活动管理相关接口
 * @author Cup
 * @date 2022/5/16
 */
@RestController
@RequestMapping("/api/v1/mp/admin/marketing")
@Api(tags = "营销活动管理相关接口")
public class MarketingMgrController extends BaseApiController {

    @Autowired
    private IMarketingService marketingService;

    @Log(title = "营销活动新增", businessType = BusinessType.INSERT)
    @ApiOperation(value = "营销活动新增")
    @PostMapping("/create")
    @PreAuthorize("@ss.hasPermi('business:marketing:add')")
    public AjaxResult create(@Validated @RequestBody MarketingCreateParam marketingCreateParam) {
        marketingService.createMarketing(marketingCreateParam);
        return AjaxResult.success();
    }

    @PostMapping("/update")
    @PreAuthorize("@ss.hasPermi('business:marketing:edit')")
    @ApiOperation("修改营销活动")
    public AjaxResult update(@Validated @RequestBody MarketingUpdateParam marketingUpdateParam) {
        marketingService.updateMarketing(marketingUpdateParam);
        return AjaxResult.success();
    }

    @PostMapping("/list")
    @ApiOperation("营销活动列表")
    public TableDataInfo list(@RequestBody MarketingQueryParam marketingQueryParam) {
        startPage();
        List<MarketingListVO> list =  marketingService.listMarketing(marketingQueryParam);
        return getDataTable(list);
    }

}
